@@ -6,16 +6,16 @@ from io import BytesIO
 from tempfile import mkdtemp
 from textwrap import dedent
 
+from pytest import raises, mark
+
 import dnaio
 from dnaio import (
     FileFormatError, FastaFormatError, FastqFormatError,
     FastaReader, FastqReader, InterleavedSequenceReader,
     FastaWriter, FastqWriter, InterleavedSequenceWriter,
     PairedSequenceReader)
-from dnaio import _sequence_names_match
-from dnaio._core import Sequence
+from dnaio import _sequence_names_match, Sequence
 
-from pytest import raises, mark
 
 # files tests/data/simple.fast{q,a}
 simple_fastq = [
@@ -82,18 +82,18 @@ class TestFastaReader:
         filename = "tests/data/simple.fasta"
         with open(filename, 'rb') as f:
             assert not f.closed
-            reads = list(dnaio.open(f))
+            _ = list(dnaio.open(f))
             assert not f.closed
         assert f.closed
 
         with FastaReader(filename) as sr:
             tmp_sr = sr
             assert not sr._file.closed
-            reads = list(sr)
+            _ = list(sr)
             assert not sr._file.closed
         assert tmp_sr._file is None
         # Open it a second time
-        with FastaReader(filename) as sr:
+        with FastaReader(filename):
             pass
 
 
@@ -112,7 +112,7 @@ class TestFastqReader:
     def test_fastqreader_buffersize_too_small(self):
         with raises(ValueError):
             with FastqReader("tests/data/simple.fastq", buffer_size=0) as f:
-                reads = list(f)
+                _ = list(f)  # pragma: no cover
 
     def test_fastqreader_dos(self):
         # DOS line breaks
@@ -127,7 +127,7 @@ class TestFastqReader:
     def test_fastq_wrongformat(self):
         with raises(FastqFormatError) as info:
             with FastqReader("tests/data/withplus.fastq") as f:
-                list(f)
+                list(f)  # pragma: no cover
         assert info.value.line == 2
 
     def test_empty_fastq(self):
@@ -171,7 +171,7 @@ class TestFastqReader:
         buffer_size = len('@r\nACG\n+\n')
         with raises(FastqFormatError) as info:
             with FastqReader(fastq, buffer_size=buffer_size) as fq:
-                list(fq)
+                list(fq)  # pragma: no cover
         assert 'Length of sequence and qualities differ' in info.value.message
         assert info.value.line == 3
 
@@ -212,7 +212,7 @@ class TestFastqReader:
         with FastqReader(filename) as sr:
             tmp_sr = sr
             assert not sr._file.closed
-            reads = list(sr)
+            _ = list(sr)
             assert not sr._file.closed
         assert tmp_sr._file is None
 
@@ -231,7 +231,7 @@ class TestFastqReader:
         fastq = BytesIO(b'@r1\nACG\n+xy\n')
         with raises(FastqFormatError) as info:
             with FastqReader(fastq) as fq:
-                list(fq)
+                list(fq)  # pragma: no cover
         assert "Sequence descriptions don't match" in info.value.message
 
 
@@ -281,7 +281,8 @@ class TestOpen:
             assert isinstance(f, FastaWriter)
             for seq in simple_fastq:
                 f.write(seq)
-        assert list(dnaio.open(path)) == simple_fasta
+        with dnaio.open(path) as f:
+            assert list(f) == simple_fasta
 
     def test_autodetect_fastq_format(self):
         path = os.path.join(self._tmpdir, 'tmp.fastq')
@@ -289,7 +290,19 @@ class TestOpen:
             assert isinstance(f, FastqWriter)
             for seq in simple_fastq:
                 f.write(seq)
-        assert list(dnaio.open(path)) == simple_fastq
+        with dnaio.open(path) as f:
+            assert list(f) == simple_fastq
+
+    def test_autodetect_fastq_weird_name(self):
+        path = os.path.join(self._tmpdir, 'tmp.fastq.gz')
+        with dnaio.open(path, mode='w') as f:
+            assert isinstance(f, FastqWriter)
+            for seq in simple_fastq:
+                f.write(seq)
+        weird_path = os.path.join(self._tmpdir, 'tmp.weird.gz')
+        os.rename(path, weird_path)
+        with dnaio.open(weird_path) as f:
+            assert list(f) == simple_fastq
 
     def test_fastq_qualities_missing(self):
         path = os.path.join(self._tmpdir, 'tmp.fastq')
@@ -432,10 +445,23 @@ class TestInterleavedWriter:
         with InterleavedSequenceWriter(bio) as writer:
             for read1, read2 in reads:
                 writer.write(read1, read2)
-        assert bio.getvalue() == b'@A/1 comment\nTTA\n+\n##H\n@A/2 comment\nGCT\n+\nHH#\n@B/1\nCC\n+\nHH\n@B/2\nTG\n+\n#H\n'
+        assert bio.getvalue() == (
+            b'@A/1 comment\nTTA\n+\n##H\n'
+            b'@A/2 comment\nGCT\n+\nHH#\n'
+            b'@B/1\nCC\n+\nHH\n'
+            b'@B/2\nTG\n+\n#H\n'
+        )
 
 
 class TestPairedSequenceReader:
+    def test_read(self):
+        s1 = BytesIO(b'@r1\nACG\n+\nHHH\n')
+        s2 = BytesIO(b'@r2\nGTT\n+\n858\n')
+        with PairedSequenceReader(s1, s2) as psr:
+            assert [
+                (Sequence("r1", "ACG", "HHH"), Sequence("r2", "GTT", "858")),
+            ] == list(psr)
+
     def test_sequence_names_match(self):
         def match(name1, name2):
             seq1 = Sequence(name1, 'ACGT')
